/*
 *  swimaciota.h
 *  swimac
 *
 *  Created by Jerry Pickering on 1/17/08.
 *  Copyright 2008 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifndef __SWIMACIOTA_H__
#define __SWIMACIOTA_H__

#ifdef __cplusplus
extern "C"	{
#endif

#import "swimacrcodes.h"
#import "swimacdatatypes.h"
#import "swimacstructs.h"

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiStartIOTASession - Start Embedded IOTA session
//
// Purpose:     This function will be used to issue a command to modem to start the
//				embedded iota session. 
//				
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:		IOTA session will be started upon calling this API. indication of sessiona and all its 
//				will be notified thru notification.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiStartIOTASession(SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiStopIOTASession - Stop Embedded IOTA session
//
// Purpose:     This function will be used to issue a command to modem to stop the
//				embedded iota session. 
//				
// Parameters:  timeout[IN]             Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:		IOTA session will be stoped upon calling this API. indication of session and all its 
//				will be notified thru notification.	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiStopIOTASession(SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetIOTADisable - Disable/Enable IOTA
//
// Purpose:     This function will be used to issue a command to modem to 
//				disable/enable embedded iota. 
//				
// Parameters:  bDisable[IN]            TRUE: Disable; FALSE: Enable.
// Parameters:  timeout[IN]             Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:		With paramerter bDisable set to TRUE, current IOTA session will 
//              be canceled upon calling this API, and network initiated IOTA 
//              will not happen thereafter. Call this API with bDisable set to 
//              FALSE to enable IOTA.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetIOTADisable(bool bDisable, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetIOTADisable - Disable/Enable IOTA
//
// Purpose:     This function will be used to issue a command to modem to 
//				get iota disable/enable state. 
//				
// Parameters:  pbDisable[IN]           pointer to save return value.
//                                      TRUE: IOTA is disabled; FALSE: Enabled.
// Parameters:  timeout[IN]             Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:		
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetIOTADisable(bool *pbDisable, SWI_U32 timeout);


//**********************************************************************************
//	SwiGetIOTAData
//		This call returns all the IOTA data in one structure
//		the primary use is to check all the "GET" calls for
//		IOTA
//**********************************************************************************
typedef struct allIOTAData
{
	SWI_RCODE	_ret[1];
	bool		_iotaDisabled;
} allIOTAData;

SWI_RCODE SwiGetIOTAData(allIOTAData *data);

#ifdef __cplusplus
}
#endif

#endif // __SWIMACIOTA_H__
